addpath(genpath('.\m_map_toolbox\'))

%% Plot the track of all Triaxus towed in one voyage
clear
clc

% Annotate the parameters of the IMOS data
ssh_dir = '.\data\in2016v04\satellite\';
chl_dir = '.\data\in2016v04\satellite\';
uwy_dir = '.\data\in2016v04\uwy\';
triaxus_dir = '.\data\in2016v04\triaxus\avg\';
adt_file = ([ssh_dir,'sla_tow1.nc']);
chl_file = ([chl_dir,'chl_tow1_mean.nc']);
fn=([uwy_dir,'in2016_v04uwy.nc']);
nt = ([triaxus_dir,'deployment1Avg.nc']);

% Load most recent SSH image and Triaxus trajectory data
lon=ncread(adt_file,'LONGITUDE');
lat=ncread(adt_file,'LATITUDE');
u1=ncread(adt_file,'UCUR');
v1=ncread(adt_file,'VCUR');
chl_lon=ncread(chl_file,'longitude');
chl_lat=ncread(chl_file,'latitude');
chl_old=ncread(chl_file,'chl_oc3');
chl=log(chl_old);
chl_time=ncread(chl_file,'time')+datenum(1985,1,1);
uwy_lat = ncread(fn,'latitude');
uwy_lon = ncread(fn,'longitude');
T.lat=ncread(nt,'latitude');
T.lon=ncread(nt,'longitude');

u(:,:,1)=u1(:,:,1);
v(:,:,1)=v1(:,:,1);
[x, y] = meshgrid(lon, lat);

%% Plotting

% figure('units','normalized','outerposition',[0 0 1 1])
m_proj('Equidistant Cylindrical','lat',[-35 -33.6],'long',[151 153]); %Projection mode and drawing range settings
m_gshhs('lc1','patch',[0.98 0.98 0.98],'EdgeColor',[0.98 0.98 0.98]); %Line and color block color settings
m_grid('box','none','linest','none','linewidth',0.1,'tickdir','out','backcolor',[0.7020 0.8588 0.9098],'fontsize',18); %Border and grid settings
m_pcolor(chl_lon,chl_lat,nanmean(chl,3)')
set(gca,'FontSize',18);
shading interp
hold on

m_gshhs_h('save','gumby'); 
m_usercoast('gumby','patch',[.5 .5 .5],'edgecolor','none');
m_grid('linewidth',2,'tickdir','out'); % Scales
m_quiver(x,y,u',v', 'color', 'k', 'linewidth', 0.75, 'MaxHeadSize', 0.1);
colormap('parula');
caxis([-1 0.5])
brighten(0.2)
c=colorbar;
set(gca,'fontsize',18);
ylabel(colorbar,'log(chl-a)(mg/m^3)', 'fontsize', 18,'Fontweight','bold')
str = strcat({'(b) Voyage IN2016V04 Tow 1 Chl-a: '},datestr(chl_time(1)-67570),{'-'},datestr(chl_time(end)-67570))
title(str,'fontsize',18)
hold on

m_plot(T.lon,T.lat,'w','linewidth',2)
m_plot(T.lon(4100:14330),T.lat(4100:14330),'r','linewidth',2)
m_plot(T.lon(1),T.lat(1),'o','linewidth',1,'color','w')