addpath(genpath('.\m_map_toolbox\'))

%% Plot the track of all Triaxus towed in one voyage
clear
clc

% Annotate the parameters of the IMOS data
ssh_dir = '.\data\in2016v04\satellite\';
uwy_dir = '.\data\in2016v04\uwy\';
triaxus_dir = '.\data\in2016v04\triaxus\avg\';
adt_file = ([ssh_dir,'sla_tow4.nc']); % Absolute dynamic topography
fn=([uwy_dir,'in2016_v04uwy.nc']);
nt = ([triaxus_dir,'deployment3Leg2Avg.nc']);

% Load most recent SSH image and Triaxus trajectory data
sla_lon=ncread(adt_file,'LONGITUDE');
sla_lat=ncread(adt_file,'LATITUDE');
sla=ncread(adt_file,'GSLA');
adt_lon=ncread(adt_file,'LONGITUDE');
adt_lat=ncread(adt_file,'LATITUDE');
adt=ncread(adt_file,'GSLA');
adt_time=ncread(adt_file,'TIME')+datenum(1985,1,1);
uwy_lat = ncread(fn,'latitude');
uwy_lon = ncread(fn,'longitude');
T.lat=ncread(nt,'latitude');
T.lon=ncread(nt,'longitude');
u1=ncread(adt_file,'UCUR');
v1=ncread(adt_file,'VCUR');

u(:,:,1)=u1(:,:,1);
v(:,:,1)=v1(:,:,1);
[x, y] = meshgrid(adt_lon, adt_lat);

%% Plotting
figure('units','normalized','outerposition',[0 0 1 1])
clf

m_proj('Equidistant Cylindrical','lat',[-36 -34],'long',[150 153]); %Projection mode and drawing range settings
m_gshhs('lc1','patch',[0.98 0.98 0.98],'EdgeColor',[0.98 0.98 0.98]); %Line and color block color settings
m_grid('box','none','linest','none','linewidth',0.1,'tickdir','out','backcolor',[0.7020 0.8588 0.9098],'fontsize',18); %Border and grid settings
m_pcolor(sla_lon,sla_lat,nanmean(sla,3)') %Plot SLA images
set(gca,'FontSize',15);
shading interp

m_gshhs_h('save','IN2016V04'); 
m_usercoast('IN2016V04','patch',[.5 .5 .5],'edgecolor','none');
m_grid('linewidth',2,'tickdir','out'); % Scales
colormap('parula');
caxis([-0.4 0.7])
brighten(0.2)
c=colorbar;
set(gca,'fontsize',18);
ylabel(colorbar,'Sea level anomaly(m)', 'fontsize', 18,'Fontweight','bold')
str = strcat({'(d) Voyage IN2016V04 Tow 4 SLA: '},datestr(adt_time(1)))
title(str,'fontsize',18, 'fontweigh', 'bold')
hold on

m_plot(T.lon,T.lat,'w','linewidth',2)
m_plot(T.lon(1090:13705),T.lat(1090:13705),'r','linewidth',2)
m_plot(T.lon(1),T.lat(1),'o','linewidth',1,'color','w')
m_quiver(x,y,u',v', 'color', 'k', 'linewidth', 0.75, 'MaxHeadSize', 0.1);
[c,hb] =m_contour(adt_lon,adt_lat,adt(:,:,1)',[-0.4:.02:0.7],'linest','-','color',[0.5,0.5,0.5],'linewidth',0.1);
clabel(c,hb,[-0.4:.04:0.7]);