addpath(genpath('.\m_map_toolbox\'))

%% Plot the track of all Triaxus towed in one voyage
clear
clc

% Annotate the parameters of the IMOS data
ssh_dir = '.\data\in2016v04\satellite\';
uwy_dir = '.\data\in2016v04\uwy\';
triaxus_dir = '.\data\in2016v04\triaxus\avg\';
adt_file = ([ssh_dir,'sla_tows_1_2_4.nc']); % Absolute dynamic topography
fn=([uwy_dir,'in2016_v04uwy.nc']);
nt_1 = ([triaxus_dir,'deployment1Avg.nc']);
nt_2 = ([triaxus_dir,'deployment2Avg.nc']);
nt_4 = ([triaxus_dir,'deployment3Leg2Avg.nc']);

% Load most recent SSH image and Triaxus trajectory data
sla_lon=ncread(adt_file,'LONGITUDE');
sla_lat=ncread(adt_file,'LATITUDE');
sla=ncread(adt_file,'GSLA');
adt_lon=ncread(adt_file,'LONGITUDE');
adt_lat=ncread(adt_file,'LATITUDE');
adt=ncread(adt_file,'GSLA');
adt_time=ncread(adt_file,'TIME')+datenum(1985,1,1);
uwy_lat = ncread(fn,'latitude');
uwy_lon = ncread(fn,'longitude');
T1.lat=ncread(nt_1,'latitude');
T1.lon=ncread(nt_1,'longitude');
T2.lat=ncread(nt_2,'latitude');
T2.lon=ncread(nt_2,'longitude');
T4.lat=ncread(nt_4,'latitude');
T4.lon=ncread(nt_4,'longitude');
u1=ncread(adt_file,'UCUR');
v1=ncread(adt_file,'VCUR');

u(:,:,1)=u1(:,:,1);
v(:,:,1)=v1(:,:,1);
[x, y] = meshgrid(adt_lon, adt_lat);

%% Plotting
figure('units','normalized','outerposition',[0 0 1 1])
clf

m_proj('Equidistant Cylindrical','lat',[-37 -32],'long',[150 156]); %Projection mode and drawing range settings
m_gshhs('lc1','patch',[0.98 0.98 0.98],'EdgeColor',[0.98 0.98 0.98]); %Line and color block color settings
m_grid('box','none','linest','none','linewidth',0.1,'tickdir','out','backcolor',[0.7020 0.8588 0.9098],'fontsize',18); %Border and grid settings
m_pcolor(sla_lon,sla_lat,nanmean(sla,3)') %Plot SLA images
set(gca,'FontSize',15);
shading interp

m_gshhs_h('save','IN2016V04'); 
m_usercoast('IN2016V04','patch',[.5 .5 .5],'edgecolor','none');
m_grid('linewidth',2,'tickdir','out'); % Scales
colormap('parula');
caxis([-0.4 0.65])
brighten(0.2)
c=colorbar;
set(gca,'fontsize',18);
ylabel(colorbar,'Sea level anomaly(m)', 'fontsize', 20,'Fontweight','bold')
str = strcat({'Voyage IN2016V04 SLA: '},datestr(adt_time(1)),{'-'},datestr(adt_time(end)))
title(str,'fontsize',18)
hold on

m_plot(uwy_lon,uwy_lat,':','linewidth',1.5,'color','w');
p2=m_plot(T1.lon,T1.lat,'k','linewidth',2);hold on;
p3=m_plot(T2.lon,T2.lat,'r','linewidth',2);hold on;
p4=m_plot(T4.lon,T4.lat,'b','linewidth',2);hold on;
m_plot(T1.lon(1),T1.lat(1),'o','linewidth',1,'color','k');
m_plot(T2.lon(1),T2.lat(1),'o','linewidth',1,'color','r');
m_plot(T4.lon(1),T4.lat(1),'o','linewidth',1,'color','b');
p1=m_quiver(x,y,u',v', 'color', 'k', 'linewidth', 0.75, 'MaxHeadSize', 0.1);
m_text(nanmean(T1.lon([24353 1],1))+0.5,nanmean(T1.lat([24353 1],1))-1.5,'Eddy 3','fontsize',14,'color','r')
m_text(nanmean(T2.lon([9076 1],1))+0.9,nanmean(T2.lat([9076 1],1))-1.2,'Eddy 2','fontsize',14,'color','r')
[c,hb] =m_contour(adt_lon,adt_lat,adt(:,:,1)',[-0.4:.05:0.65],'linest','-','color',[0.5,0.5,0.5],'linewidth',0.1);
clabel(c,hb,[-0.4:.1:0.65]);
pp=legend([p1,p2,p3,p4], 'geostrophic velocity','in2016v04__tow1','in2016v04__tow2','in2016v04__tow4','location','northwest','fontsize',12);
set(pp,'box','off');