addpath(genpath('.\m_map_toolbox\'))

%% Plot the track of all Triaxus towed in one voyage
clear
clc

% Annotate the parameters of the IMOS data
ssh_dir = '.\data\in2018t01\satellite\';
uwy_dir = '.\data\in2018t01\uwy\';
triaxus_dir = '.\data\in2018t01\triaxus\avg\';
adt_file = ([ssh_dir,'sla_alltow.nc']); % Absolute dynamic topography
fn=([uwy_dir,'in2018_t01uwy.nc']);
nt_2 = ([triaxus_dir,'deployment2Avg.nc']);

% Load most recent SSH image and Triaxus trajectory data
sla_lon=ncread(adt_file,'LONGITUDE');
sla_lat=ncread(adt_file,'LATITUDE');
sla=ncread(adt_file,'GSLA');
adt_lon=ncread(adt_file,'LONGITUDE');
adt_lat=ncread(adt_file,'LATITUDE');
adt=ncread(adt_file,'GSLA');
adt_time=ncread(adt_file,'TIME')+datenum(1985,1,1);
uwy_lat = ncread(fn,'latitude');
uwy_lon = ncread(fn,'longitude');
T2.lat=ncread(nt_2,'latitude');
T2.lon=ncread(nt_2,'longitude');
u1=ncread(adt_file,'UCUR');
v1=ncread(adt_file,'VCUR');

u(:,:,1)=u1(:,:,1);
v(:,:,1)=v1(:,:,1);
[x, y] = meshgrid(adt_lon, adt_lat);

%% Plotting
figure('units','normalized','outerposition',[0 0 1 1])
clf

m_proj('Equidistant Cylindrical','lat',[-38.6 -34],'long',[150 155]); %Projection mode and drawing range settings
m_gshhs('lc1','patch',[0.98 0.98 0.98],'EdgeColor',[0.98 0.98 0.98]); %Line and color block color settings
m_grid('box','none','linest','none','linewidth',0.1,'tickdir','out','backcolor',[0.7020 0.8588 0.9098],'fontsize',18); %Border and grid settings
m_pcolor(sla_lon,sla_lat,nanmean(sla,3)') %Plot SLA images
set(gca,'FontSize',18);
shading interp

m_gshhs_h('save','gumby'); 
m_usercoast('gumby','patch',[.5 .5 .5],'edgecolor','none');
m_grid('linewidth',2,'tickdir','out'); % Scales
colormap('parula');
caxis([-0.4 0.75]);
brighten(0.2);
ylabel(colorbar,'Sea level anomaly(m)', 'fontsize', 18,'Fontweight','bold');
str = strcat({'Voyage IN2018T01 SLA: '},datestr(adt_time(1)));
title(str,'fontsize',18);
hold on

m_plot(uwy_lon,uwy_lat,':','linewidth',1.5,'color','w');
p1=m_quiver(x,y,u',v', 'color', 'k', 'linewidth', 0.75, 'MaxHeadSize', 0.1);
p2=m_plot(T2.lon,T2.lat,'r','linewidth',2);hold on;
m_plot(T2.lon(1),T2.lat(1),'o','linewidth',1,'color','r');
m_text(nanmean(T2.lon([15406 1],1))+0.1,nanmean(T2.lat([15406 1],1))-0.9,'Eddy 1','fontsize',14,'color','r');
[c,hb] =m_contour(adt_lon,adt_lat,adt(:,:,1)',[-0.4:.05:0.75],'linest','-','color',[0.5,0.5,0.5],'linewidth',0.1);
clabel(c,hb,[-0.4:.2:0.75]);
pp=legend([p1,p2],'geostrophic velocity', 'in2018t01__tow2','location','northwest','fontsize',12);
set(pp,'box','off');