addpath(genpath('.\m_map_toolbox\'))

%% Plot the track of all Triaxus towed in one voyage
clear
clc

% Annotate the parameters of the IMOS data
sst_dir = '.\data\in2018t01\satellite\';
uwy_dir = '.\data\in2018t01\uwy\';
triaxus_dir = '.\data\in2018t01\triaxus\avg\';
sst_file = ([sst_dir,'sst_tow2.nc']); % Absolute dynamic topography
fn=([uwy_dir,'in2018_t01uwy.nc']);
nt = ([triaxus_dir,'deployment2Avg.nc']);

% Load most recent SSH image and Triaxus trajectory data
sst_lon=ncread(sst_file,'lat');
sst_lat=ncread(sst_file,'lon');
sst=ncread(sst_file,'sea_surface_temperature');
sst_dtime=ncread(sst_file,'sst_dtime');
sst_time=ncread(sst_file,'time')+datenum(1819,2,2);
uwy_lat = ncread(fn,'latitude');
uwy_lon = ncread(fn,'longitude');
T.lat=ncread(nt,'latitude');
T.lon=ncread(nt,'longitude');

sst_ce = sst - 273.15;

%% Plotting
figure('units','normalized','outerposition',[0 0 1 1])
clf

m_proj('Equidistant Cylindrical','lat',[-36 -35],'long',[150 152]); %Projection mode and drawing range settings
m_gshhs('lc1','patch',[0.98 0.98 0.98],'EdgeColor',[0.98 0.98 0.98]); %Line and color block color settings
m_grid('box','none','linest','none','linewidth',0.1,'tickdir','out','backcolor',[0.7020 0.8588 0.9098],'fontsize',18); %Border and grid settings
m_pcolor(sst_lat,sst_lon,sst_ce');
set(gca,'FontSize',18);
shading interp

m_gshhs_h('save','IN2018T01'); 
m_usercoast('IN2018T01','patch',[.5 .5 .5],'edgecolor','none');
m_grid('linewidth',2,'tickdir','out'); % Scales
colormap('jet');
caxis([18 26])
brighten(0.2)
c=colorbar;
set(gca,'fontsize',18);
ylabel(colorbar,'Sea Surface Temperature (^{\circ}C)', 'fontsize',18,'Fontweight','bold')
str = strcat({'(a) Voyage IN2018T01 Tow 2 SST: '},datestr(sst_time(1)))
title(str,'fontsize',18, 'fontweigh', 'bold')
hold on

m_plot(T.lon,T.lat,'w','linewidth',2)
m_plot(T.lon(2520:6050),T.lat(2520:6050),'r','linewidth',2)
m_plot(T.lon(1),T.lat(1),'o','linewidth',1,'color','w')
[c,hb] =m_contour(sst_lat,sst_lon,sst_ce',[18:.25:26],'linest','-','color',[0.5,0.5,0.5],'linewidth',0.1);
clabel(c,hb,[18:.5:26]);