%load triaxus data
addpath(genpath('.\gsw_matlab_toolbox\'))

clear
close all

adcp_dir = '.\data\in2016v04\sadcp\';
triaxus_dir = '.\data\in2016v04\triaxus\avgcast\';
nt = ([triaxus_dir,'deployment2AvgCast.nc']);

% Loop through each Triaxus leg, one file per leg
T.voyage ='IN2016_V04'; % We should be able to read in the voyage name from the file names
T.time=ncread(nt,'time')/60/24+datenum(1900,1,1,0,0,0);  % 60 minutes per hour, 24 hours per day - convert minutes since 1900,1,1 to days since 1900,1,1
T.lat=ncread(nt,'latitude');
T.lon=ncread(nt,'longitude');
T.D=ncread(nt,'waterDepth');
T.p=ncread(nt,'pressure');
T.T=ncread(nt,'temperature');
T.T_flags=ncread(nt,'temperatureFlag');
T.S=ncread(nt,'salinity');
T.S_flags=ncread(nt,'salinityFlag');
T.O=ncread(nt,'oxygen');
T.O_flags=ncread(nt,'oxygenFlag');
T.tran=ncread(nt,'transmissometer');
T.tran_flags=ncread(nt,'transmissometerFlag');
T.par=ncread(nt,'par');
T.par_flags=ncread(nt,'parFlag');
T.chl=ncread(nt,'chlorophyll');
T.chl_flags=ncread(nt,'chlorophyllFlag');
T.obs=ncread(nt,'obs');
T.obs_flags=ncread(nt,'obsFlag');
T.cdom=ncread(nt,'cdom');
T.cdom_flags=ncread(nt,'cdomFlag');

% calculate absolute salinity, conservative temperature, and poential
% density
T.SA =  gsw_SA_from_SP(T.S,T.p',T.lon,T.lat);  %convert practical salinity to absolute salinity
T.CT = gsw_CT_from_t(T.SA,T.T,T.p');  %assign temp to the conservative temperature at that depth
T.sigma0 = gsw_sigma0(T.SA,T.CT);
T.z= gsw_z_from_p(repmat(T.p,1,length(T.lat)),T.lat');
T.depth = gsw_depth_from_z(T.z);
T.spiciness=gsw_spiciness0(T.SA,T.CT);
T.OS = gsw_O2sol(T.SA,T.CT,T.p,T.lon,T.lat);
T.AOU = T.OS-T.O;
T.abs=100-T.tran;
T.chlx=(T.chl-min(T.chl))./(max(T.chl)-min(T.chl));
T.obsx=(T.obs-min(T.obs))./(max(T.obs)-min(T.obs));
T.ra=T.obsx-T.chlx;

%change the X-axis from latitude to distance
dist=gsw_distance(T.lon,T.lat);
T.D=cumsum([0; dist])/1000;

%calculate MLD as the depth where sigma0 is equal to sigma0 at 10 m depth +0.02
%kg/m3.
T.z= gsw_z_from_p(repmat(T.p,1,length(T.lat))',T.lat); %height which is negative in the ocean
depth = -T.z; %depth is negative height
delsig=0.03;
i=zeros(89,1);
d=zeros(89,1);
for a=1:length(T.lat)
[i(a),d(a)]=near(T.sigma0(a,1:end), 10, 1);
end
number=find(d==min(d));
z10=i(number); %depth level of reference density - this is the index into the depth array
T.mld = NaN(1,length(T.lat)); %set up the size of the array for mld
for j=1:length(T.lat)
%     disp(['j=',int2str(j)])
    sig10 = T.sigma0(j,z10);
    zind = find(T.sigma0(j,z10+1:end)>=sig10+delsig,1);
    if ~isempty(zind)
        T.mld(j) = depth(j,zind+z10);
    end
%     pause
end
clear sig10 zind

T.O_flags(T.O_flags==0)=NaN;
T.O_flags(T.O_flags==134)=NaN;
T.S_flags(T.S_flags==0)=NaN;
T.S_flags(T.S_flags==134)=NaN;
T.T_flags(T.T_flags==0)=NaN;
T.T_flags(T.T_flags==134)=NaN;
T.chl_flags(T.chl_flags==0)=NaN;
T.chl_flags(T.chl_flags==134)=NaN;
T.obs_flags(T.obs_flags==0)=NaN;
T.obs_flags(T.obs_flags==134)=NaN;
T.tran_flags(T.tran_flags==0)=NaN;
T.tran_flags(T.tran_flags==134)=NaN;
T.cdom_flags(T.cdom_flags==0)=NaN;
T.cdom_flags(T.cdom_flags==134)=NaN;

% Load ADCP data
fn=([adcp_dir,'os150nb.nc']);
adcp_lat = ncread(fn,'lat');
adcp_lon = ncread(fn,'lon');
adcp_depth = ncread(fn,'depth');
adcp_time = datenum(2016,01,01,00,00,00)+ncread(fn,'time');
adcp_u = ncread(fn,'u');
adcp_v = ncread(fn,'v');

%Find ADCP data at same times as triaxus with a 5-minute bin offset for distance between ship and
%triaxus
tstart = find(adcp_time>=T.time(1),1)-1;
tend = find(adcp_time>=T.time(end),1)-1;

lat_sec = adcp_lat(tstart:tend);
lon_sec = adcp_lon(tstart:tend);

adcp_dis=gsw_distance(lon_sec,lat_sec);
dis_sec = cumsum([0; adcp_dis])/1000;

dis_sec(dis_sec<0)=NaN;
good_index = ~isnan(dis_sec);
dis_sec = dis_sec(good_index);
dis_sec=sort(dis_sec,'descend');
u_sec = adcp_u(:,tstart:tend);
u_sec = u_sec(:,good_index);
u_sec(u_sec>=10) = NaN;
v_sec = adcp_v(:,tstart:tend);
v_sec = v_sec(:,good_index);
v_sec(v_sec>=10) = NaN;
d_sec = adcp_depth(:,tstart:tend);
t_sec = adcp_time(tstart:tend);
f_sec = gsw_f(dis_sec);
vel_sec = u_sec + v_sec ;
vel_sec(:) = sqrt(u_sec(:).^2+v_sec(:).^2);



figure(1)  %Plot physical data - T, S, O, sigma, u, v
clf

%Conservative Temperature
clims = [13.4 21.4];
subplot(3,2,1)
contourf(T.D,T.depth(:,1),T.CT','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
colormap(jet)
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','^{\circ}C','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(a) Conservative Temperature','fontsize',14)

%Absolute Salinity
clims = [35.3 36];
subplot(3,2,3)
contourf(T.D,T.depth(:,1),T.SA','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','g/kg','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(b) Absolute Salinity','fontsize',14)

%Oxygen
clims = [180 230];
subplot(3,2,5);
contourf(T.D,T.depth(:,1),T.O','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','umol/kg','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(c) Dissolved Oxygen','fontsize',14)

%Density
clims = [24.9 26.4];
subplot(3,2,2)
contourf(T.D,T.depth(:,1),T.sigma0','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','kg/m^3','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(d) Potential Density','fontsize',14)

%Spiciness
clims = [2 4.5];
subplot(3,2,4);
contourf(T.D,T.depth(:,1),T.spiciness','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','kg/m^3','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(e) Spiciness','fontsize',14)

%% calculate Nsquared

v=nan(89,1);
T.SA=[v,T.SA];
T.CT=[v,T.CT];
T.p=[0;T.p];

T.Nsquared =[]; %Set up size of Nsq array
T.pmid =[]; %Set up size of Nsq array
for j=1:length(T.lat)
    SA=[]; CT=[]; igood=[];  % Empty working variables each time
    SA = T.SA(j,:);
    CT = T.CT(j,:);
    igood = find(~isnan(SA.*CT)); % Find all levels where there is both S and T data
    if length(igood)>=2
    [T.Nsquared(j,1:length(igood)-1),T.pmid(j,1:length(igood)-1)] = gsw_Nsquared(SA(igood),CT(igood),T.p(igood),T.lat(j));
    end
end

N_squ = NaN(length(T.lat),length(T.p)-1);
N_pmid = NaN(length(T.lat),length(T.p)-1); %Set up size of Nsq array
for k=1:length(T.lat)
    SA=[]; CT=[]; igood=[];  % Empty working variables each time
    SA = T.SA(k,:);
    CT = T.CT(k,:);
    igood = find(~isnan(SA.*CT)); % Find all levels where there is both S and T data
    for m=1:length(igood)-1
       if length(igood)>=2
          N_squ(k,igood(m))=T.Nsquared(k,m);
          N_pmid(k,igood(m))=T.pmid(k,m);
       end
    end   
end

N_squ_2=[N_squ,N_squ(:,end)];
N_squ_3=0.5*(N_squ_2(:,1:end-1)+N_squ_2(:,2:end));

%Nsquared
clims = [-1.0e-03*0.1 1.0e-03*0.7];
subplot(3,2,6)
contourf(T.D,T.depth(:,1),N_squ','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
colormap(jet);
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','1/s^2','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(f) N^2','fontsize',14)

figure(2) %Plot biological data - O, trans, PAR, Chl, OBS, cdom
clf

% OBS
clims = [1.0e-05*11 1.0e-05*33];
subplot(3,2,1)
contourf(T.D,T.depth(:,1),T.obs','LineColor','none')
colormap(jet);
freezeColors;
hold on
pcolor(T.D,T.depth(:,1),T.obs_flags');
colormap(cool);
freezeColors;
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
colormap(jet)
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','m^-^1','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(a) OBS','fontsize',14)

%Chlorophyll
clims = [0 0.9];
subplot(3,2,3)
contourf(T.D,T.depth(:,1),T.chl','LineColor','none');
colormap(jet);
freezeColors;
hold on
pcolor(T.D,T.depth(:,1),T.chl_flags');
colormap(cool);
freezeColors;
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75);
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
colormap(jet);
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','ug/L','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(b) Chlorophyll','fontsize',14)

%OBS-CHL
clims = [-1 1];
ra_fig=subplot(3,2,5)
contourf(T.D,T.depth(:,1),T.ra','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
colormap(ra_fig,redblue);
caxis(clims);
xlabel('distance (km)','fontsize',14);
ylabel('depth (m)','fontsize',14);
set(get(h,'title'),'string','','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(c) OBS-CHL','fontsize',14)

% %absorption = 100% - %transmission
clims = [0.1 4.2];
subplot(3,2,2)
contourf(T.D,T.depth(:,1),T.abs','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','%','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(d) Attenuation','fontsize',14)

%Apparent Oxygen Utilization
clims = [-5 65];
subplot(3,2,4)
contourf(T.D,T.depth(:,1),T.AOU','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','umol/kg','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(e) AOU','fontsize',14)

%CDOM
clims = [1872 2165];
subplot(3,2,6)
contourf(T.D,T.depth(:,1),T.cdom','LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
ylim([0 200])
h=colorbar;
caxis(clims)
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','scaled','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(f) CDOM','fontsize',14)

figure(3)
% velocity u-component
u_fig=subplot(3,2,1);
contourf(dis_sec,d_sec(:,1),u_sec,'LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
colormap(u_fig,redblue);
caxis([-.7 .7])
ylim([0 200])
h=colorbar;
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','m/s','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(a) Subsurface Ocean Velocity u-component','fontsize',14)

% velocity v-component
v_fig=subplot(3,2,3);
contourf(dis_sec,d_sec(:,1),v_sec,'LineColor','none')
shading flat
hold on
plot(T.D,T.mld,'k','LineWidth',1.75)
set(gca,'Ydir','reverse','tickdir','out','fontsize',12);
colormap(v_fig,redblue);
caxis([-.7 .7])
ylim([0 200])
h=colorbar;
xlabel('distance (km)','fontsize',14)
ylabel('depth (m)','fontsize',14)
set(get(h,'title'),'string','m/s','fontsize',12);
[c, hb]=contour(T.D,T.depth(:,1),T.sigma0',[25:.2:26.4],'linest','-','color','k','linewidth',0.1);
clabel(c,hb,[25.2:.4:26.2]);
title('(b) Subsurface Horizontal Velocity v-component','fontsize',14)